[gtk+/xi2-for-master] No index in headers



commit 32f3b01b5b36f02527d57c437896b5f9b5ec8abc
Author: Matthias Clasen <mclasen redhat com>
Date:   Fri May 21 14:07:09 2010 -0400

    No index in headers
    
    It causes problems with system headers on some platforms.

 gdk/gdkdevice.c |   44 ++++++++++++++++++++++----------------------
 gdk/gdkdevice.h |    4 ++--
 2 files changed, 24 insertions(+), 24 deletions(-)
---
diff --git a/gdk/gdkdevice.h b/gdk/gdkdevice.h
index 3b1581a..5744825 100644
--- a/gdk/gdkdevice.h
+++ b/gdk/gdkdevice.h
@@ -219,7 +219,7 @@ gboolean       gdk_device_set_mode      (GdkDevice      *device,
 					 GdkInputMode    mode);
 
 gboolean       gdk_device_get_key       (GdkDevice       *device,
-                                         guint            index,
+                                         guint            index_,
                                          guint           *keyval,
                                          GdkModifierType *modifiers);
 void           gdk_device_set_key       (GdkDevice      *device,
@@ -228,7 +228,7 @@ void           gdk_device_set_key       (GdkDevice      *device,
 					 GdkModifierType modifiers);
 
 GdkAxisUse     gdk_device_get_axis_use  (GdkDevice         *device,
-                                         guint              index);
+                                         guint              index_);
 void           gdk_device_set_axis_use  (GdkDevice         *device,
                                          guint              index_,
                                          GdkAxisUse         use);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gdk/gdkdevice.c b/gdk/gdkdevice.c
index a19e3dc..05eebcd 100644
--- a/gdk/gdkdevice.c
+++ b/gdk/gdkdevice.c
@@ -585,11 +585,11 @@ gdk_device_set_mode (GdkDevice    *device,
 /**
  * gdk_device_get_key:
  * @device: a #GdkDevice.
  * @index: the index of the macro button to get.
  * @keyval: return value for the keyval.
  * @modifiers: return value for modifiers.
  *
  * If @index has a valid keyval, this function will return %TRUE
  * and fill in @keyval and @modifiers with the keyval settings.
  *
  * Returns: %TRUE if keyval is set for @index.
@@ -598,22 +598,22 @@ gdk_device_set_mode (GdkDevice    *device,
  **/
 gboolean
 gdk_device_get_key (GdkDevice       *device,
-                    guint            index,
+                    guint            index_,
                     guint           *keyval,
                     GdkModifierType *modifiers)
 {
   g_return_val_if_fail (GDK_IS_DEVICE (device), FALSE);
   g_return_val_if_fail (index < device->num_keys, FALSE);
 
-  if (!device->keys[index].keyval &&
-      !device->keys[index].modifiers)
+  if (!device->keys[index_].keyval &&
+      !device->keys[index_].modifiers)
     return FALSE;
 
   if (keyval)
-    *keyval = device->keys[index].keyval;
+    *keyval = device->keys[index_].keyval;
 
   if (modifiers)
-    *modifiers = device->keys[index].modifiers;
+    *modifiers = device->keys[index_].modifiers;
 
   return TRUE;
 }
@@ -644,9 +644,9 @@ gdk_device_set_key (GdkDevice      *device,
 /**
  * gdk_device_get_axis_use:
  * @device: a #GdkDevice.
  * @index: the index of the axis.
  *
  * Returns the axis use for @index.
  *
  * Returns: a #GdkAxisUse specifying how the axis is used.
  *
@@ -654,12 +654,12 @@ gdk_device_set_key (GdkDevice      *device,
  **/
 GdkAxisUse
 gdk_device_get_axis_use (GdkDevice *device,
-                         guint      index)
+                         guint      index_)
 {
   g_return_val_if_fail (GDK_IS_DEVICE (device), GDK_AXIS_IGNORE);
   g_return_val_if_fail (index < device->num_axes, GDK_AXIS_IGNORE);
 
-  return device->axes[index].use;
+  return device->axes[index_].use;
 }
 
 /**
@@ -1182,21 +1182,21 @@ find_axis_info (GArray     *array,
 
 GdkAxisUse
 _gdk_device_get_axis_use (GdkDevice *device,
-                          guint      index)
+                          guint      index_)
 {
   GdkDevicePrivate *priv;
   GdkAxisInfo info;
 
   priv = GDK_DEVICE_GET_PRIVATE (device);
 
-  info = g_array_index (priv->axes, GdkAxisInfo, index);
+  info = g_array_index (priv->axes, GdkAxisInfo, index_);
   return info.use;
 }
 
 gboolean
 _gdk_device_translate_window_coord (GdkDevice *device,
                                     GdkWindow *window,
-                                    guint      index,
+                                    guint      index_,
                                     gdouble    value,
                                     gdouble   *axis_value)
 {
@@ -1214,10 +1214,10 @@ _gdk_device_translate_window_coord (GdkDevice *device,
 
   priv = GDK_DEVICE_GET_PRIVATE (device);
 
-  if (index >= priv->axes->len)
+  if (index_ >= priv->axes->len)
     return FALSE;
 
-  axis_info = g_array_index (priv->axes, GdkAxisInfo, index);
+  axis_info = g_array_index (priv->axes, GdkAxisInfo, index_);
 
   if (axis_info.use != GDK_AXIS_X &&
       axis_info.use != GDK_AXIS_Y)
@@ -1313,7 +1313,7 @@ _gdk_device_translate_screen_coord (GdkDevice *device,
                                     GdkWindow *window,
                                     gint       window_root_x,
                                     gint       window_root_y,
-                                    guint      index,
+                                    guint      index_,
                                     gdouble    value,
                                     gdouble   *axis_value)
 {
@@ -1327,10 +1327,10 @@ _gdk_device_translate_screen_coord (GdkDevice *device,
 
   priv = GDK_DEVICE_GET_PRIVATE (device);
 
-  if (index >= priv->axes->len)
+  if (index_ >= priv->axes->len)
     return FALSE;
 
-  axis_info = g_array_index (priv->axes, GdkAxisInfo, index);
+  axis_info = g_array_index (priv->axes, GdkAxisInfo, index_);
 
   if (axis_info.use != GDK_AXIS_X &&
       axis_info.use != GDK_AXIS_Y)
@@ -1366,7 +1366,7 @@ _gdk_device_translate_screen_coord (GdkDevice *device,
 
 gboolean
 _gdk_device_translate_axis (GdkDevice *device,
-                            guint      index,
+                            guint      index_,
                             gdouble    value,
                             gdouble   *axis_value)
 {
@@ -1376,10 +1376,10 @@ _gdk_device_translate_axis (GdkDevice *device,
 
   priv = GDK_DEVICE_GET_PRIVATE (device);
 
-  if (index >= priv->axes->len)
+  if (index_ >= priv->axes->len)
     return FALSE;
 
-  axis_info = g_array_index (priv->axes, GdkAxisInfo, index);
+  axis_info = g_array_index (priv->axes, GdkAxisInfo, index_);
 
   if (axis_info.use == GDK_AXIS_X ||
       axis_info.use == GDK_AXIS_Y)
@@ -585,11 +585,11 @@ gdk_device_set_mode (GdkDevice    *device,
  * gdk_device_get_key:
  * @device: a #GdkDevice.
- * @index: the index of the macro button to get.
+ * @index_: the index of the macro button to get.
  * @keyval: return value for the keyval.
  * @modifiers: return value for modifiers.
@@ -585,11 +585,11 @@ gdk_device_set_mode (GdkDevice    *device,
  * @modifiers: return value for modifiers.
  *
- * If @index has a valid keyval, this function will return %TRUE
+ * If @index_ has a valid keyval, this function will return %TRUE
  * and fill in @keyval and @modifiers with the keyval settings.
  *
@@ -644,9 +644,9 @@ gdk_device_set_key (GdkDevice      *device,
  * gdk_device_get_axis_use:
  * @device: a #GdkDevice.
- * @index: the index of the axis.
+ * @index_: the index of the axis.
  *
@@ -644,9 +644,9 @@ gdk_device_set_key (GdkDevice      *device,
  *
- * Returns the axis use for @index.
+ * Returns the axis use for @index_.
  *
  * Returns: a #GdkAxisUse specifying how the axis is used.